#[repr(i32)]pub enum EBrowserFeatureStatus {
Show 14 variants
KEBrowserFeatureStatusInvalid = 0,
KEBrowserFeatureStatusNotFound = 1,
KEBrowserFeatureStatusUnknown = 2,
KEBrowserFeatureStatusDisabledSoftware = 3,
KEBrowserFeatureStatusDisabledOff = 4,
KEBrowserFeatureStatusDisabledOffOk = 5,
KEBrowserFeatureStatusUnavailableSoftware = 6,
KEBrowserFeatureStatusUnavailableOff = 7,
KEBrowserFeatureStatusUnavailableOffOk = 8,
KEBrowserFeatureStatusEnabledReadback = 9,
KEBrowserFeatureStatusEnabledForce = 10,
KEBrowserFeatureStatusEnabled = 11,
KEBrowserFeatureStatusEnabledOn = 12,
KEBrowserFeatureStatusEnabledForceOn = 13,
}Variants
KEBrowserFeatureStatusInvalid = 0
KEBrowserFeatureStatusNotFound = 1
KEBrowserFeatureStatusUnknown = 2
KEBrowserFeatureStatusDisabledSoftware = 3
KEBrowserFeatureStatusDisabledOff = 4
KEBrowserFeatureStatusDisabledOffOk = 5
KEBrowserFeatureStatusEnabledReadback = 9
KEBrowserFeatureStatusEnabledForce = 10
KEBrowserFeatureStatusEnabled = 11
KEBrowserFeatureStatusEnabledOn = 12
KEBrowserFeatureStatusEnabledForceOn = 13
Implementations
Sourceimpl EBrowserFeatureStatus
impl EBrowserFeatureStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EBrowserFeatureStatus.
Sourcepub fn from_i32(value: i32) -> Option<EBrowserFeatureStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EBrowserFeatureStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EBrowserFeatureStatus, or None if value is not a valid variant.
Sourceimpl EBrowserFeatureStatus
impl EBrowserFeatureStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.