#[repr(i32)]pub enum ECommentThreadType {
Show 22 variants
KECommentThreadTypeInvalid = 0,
KECommentThreadTypeScreenshotDeprecated = 1,
KECommentThreadTypeWorkshopAccountDeveloper = 2,
KECommentThreadTypeWorkshopAccountPublic = 3,
KECommentThreadTypePublishedFileDeveloper = 4,
KECommentThreadTypePublishedFilePublic = 5,
KECommentThreadTypeTest = 6,
KECommentThreadTypeForumTopic = 7,
KECommentThreadTypeRecommendation = 8,
KECommentThreadTypeVideoDeprecated = 9,
KECommentThreadTypeProfile = 10,
KECommentThreadTypeNewsPost = 11,
KECommentThreadTypeClan = 12,
KECommentThreadTypeClanAnnouncement = 13,
KECommentThreadTypeClanEvent = 14,
KECommentThreadTypeUserStatusPublished = 15,
KECommentThreadTypeUserReceivedNewGame = 16,
KECommentThreadTypePublishedFileAnnouncement = 17,
KECommentThreadTypeModeratorMessage = 18,
KECommentThreadTypeClanCuratedApp = 19,
KECommentThreadTypeQAndASession = 20,
KECommentThreadTypeMax = 21,
}Variants
KECommentThreadTypeInvalid = 0
KECommentThreadTypeScreenshotDeprecated = 1
KECommentThreadTypeWorkshopAccountDeveloper = 2
KECommentThreadTypeWorkshopAccountPublic = 3
KECommentThreadTypePublishedFileDeveloper = 4
KECommentThreadTypePublishedFilePublic = 5
KECommentThreadTypeTest = 6
KECommentThreadTypeForumTopic = 7
KECommentThreadTypeRecommendation = 8
KECommentThreadTypeVideoDeprecated = 9
KECommentThreadTypeProfile = 10
KECommentThreadTypeNewsPost = 11
KECommentThreadTypeClan = 12
KECommentThreadTypeClanAnnouncement = 13
KECommentThreadTypeClanEvent = 14
KECommentThreadTypeUserStatusPublished = 15
KECommentThreadTypeUserReceivedNewGame = 16
KECommentThreadTypePublishedFileAnnouncement = 17
KECommentThreadTypeModeratorMessage = 18
KECommentThreadTypeClanCuratedApp = 19
KECommentThreadTypeQAndASession = 20
KECommentThreadTypeMax = 21
Implementations
Sourceimpl ECommentThreadType
impl ECommentThreadType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ECommentThreadType.
Sourcepub fn from_i32(value: i32) -> Option<ECommentThreadType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ECommentThreadType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ECommentThreadType, or None if value is not a valid variant.
Sourceimpl ECommentThreadType
impl ECommentThreadType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.