#[repr(i32)]pub enum ECommunityItemClass {
Show 18 variants
KECommunityItemClassInvalid = 0,
KECommunityItemClassBadge = 1,
KECommunityItemClassGameCard = 2,
KECommunityItemClassProfileBackground = 3,
KECommunityItemClassEmoticon = 4,
KECommunityItemClassBoosterPack = 5,
KECommunityItemClassConsumable = 6,
KECommunityItemClassGameGoo = 7,
KECommunityItemClassProfileModifier = 8,
KECommunityItemClassScene = 9,
KECommunityItemClassSalienItem = 10,
KECommunityItemClassSticker = 11,
KECommunityItemClassChatEffect = 12,
KECommunityItemClassMiniProfileBackground = 13,
KECommunityItemClassAvatarFrame = 14,
KECommunityItemClassAnimatedAvatar = 15,
KECommunityItemClassSteamDeckKeyboardSkin = 16,
KECommunityItemClassSteamDeckStartupMovie = 17,
}Variants
KECommunityItemClassInvalid = 0
KECommunityItemClassBadge = 1
KECommunityItemClassGameCard = 2
KECommunityItemClassProfileBackground = 3
KECommunityItemClassEmoticon = 4
KECommunityItemClassBoosterPack = 5
KECommunityItemClassConsumable = 6
KECommunityItemClassGameGoo = 7
KECommunityItemClassProfileModifier = 8
KECommunityItemClassScene = 9
KECommunityItemClassSalienItem = 10
KECommunityItemClassSticker = 11
KECommunityItemClassChatEffect = 12
KECommunityItemClassMiniProfileBackground = 13
KECommunityItemClassAvatarFrame = 14
KECommunityItemClassAnimatedAvatar = 15
KECommunityItemClassSteamDeckKeyboardSkin = 16
KECommunityItemClassSteamDeckStartupMovie = 17
Implementations
Sourceimpl ECommunityItemClass
impl ECommunityItemClass
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ECommunityItemClass.
Sourcepub fn from_i32(value: i32) -> Option<ECommunityItemClass>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ECommunityItemClass>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ECommunityItemClass, or None if value is not a valid variant.
Sourceimpl ECommunityItemClass
impl ECommunityItemClass
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.