#[repr(i32)]pub enum EContentReportResolution {
Show 18 variants
KEContentReportResolutionUnresolved = 0,
KEContentReportResolutionAcquitted = 1,
KEContentReportResolutionRemoved = 2,
KEContentReportResolutionRelabelled = 3,
KEContentReportResolutionSuspicious = 4,
KEContentReportResolutionHarassmentStrike = 5,
KEContentReportResolutionPurged = 6,
KEContentReportResolutionDisconnectedFromApp = 7,
KEContentReportResolutionSuspiciousIncludingUpvoters = 8,
KEContentReportResolutionVisibilityChanged = 9,
KEContentReportResolutionCountryRestrictionsChanged = 10,
KEContentReportResolutionRemoveAndWarn = 11,
KEContentReportResolutionRemoveAndBan = 12,
KEContentReportResolutionRemoveAndKick = 13,
KEContentReportResolutionSanctioned = 14,
KEContentReportResolutionSustained = 15,
KEContentReportResolutionBroken = 16,
KEContentReportResolutionMax = 17,
}Variants
KEContentReportResolutionUnresolved = 0
KEContentReportResolutionAcquitted = 1
KEContentReportResolutionRemoved = 2
KEContentReportResolutionRelabelled = 3
KEContentReportResolutionSuspicious = 4
KEContentReportResolutionHarassmentStrike = 5
KEContentReportResolutionPurged = 6
KEContentReportResolutionDisconnectedFromApp = 7
KEContentReportResolutionSuspiciousIncludingUpvoters = 8
KEContentReportResolutionVisibilityChanged = 9
KEContentReportResolutionCountryRestrictionsChanged = 10
KEContentReportResolutionRemoveAndWarn = 11
KEContentReportResolutionRemoveAndBan = 12
KEContentReportResolutionRemoveAndKick = 13
KEContentReportResolutionSanctioned = 14
KEContentReportResolutionSustained = 15
KEContentReportResolutionBroken = 16
KEContentReportResolutionMax = 17
Implementations
Sourceimpl EContentReportResolution
impl EContentReportResolution
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EContentReportResolution.
Sourcepub fn from_i32(value: i32) -> Option<EContentReportResolution>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EContentReportResolution>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EContentReportResolution, or None if value is not a valid variant.
Sourceimpl EContentReportResolution
impl EContentReportResolution
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.