#[repr(i32)]pub enum EForumType {
KEForumTypeInvalid = 0,
KEForumTypeGeneral = 1,
KEForumTypeReportedPosts = 2,
KEForumTypeWorkshop = 3,
KEForumTypePublishedFile = 4,
KEForumTypeTrading = 5,
KEForumTypePlayTest = 6,
KEForumTypeEvent = 7,
KEForumTypeMax = 8,
}Variants
KEForumTypeInvalid = 0
KEForumTypeGeneral = 1
KEForumTypeReportedPosts = 2
KEForumTypeWorkshop = 3
KEForumTypePublishedFile = 4
KEForumTypeTrading = 5
KEForumTypePlayTest = 6
KEForumTypeEvent = 7
KEForumTypeMax = 8
Implementations
Sourceimpl EForumType
impl EForumType
Sourceimpl EForumType
impl EForumType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.