#[repr(i32)]pub enum EProfileCustomizationType {
Show 25 variants
KEProfileCustomizationTypeInvalid = 0,
KEProfileCustomizationTypeRareAchievementShowcase = 1,
KEProfileCustomizationTypeGameCollector = 2,
KEProfileCustomizationTypeItemShowcase = 3,
KEProfileCustomizationTypeTradeShowcase = 4,
KEProfileCustomizationTypeBadges = 5,
KEProfileCustomizationTypeFavoriteGame = 6,
KEProfileCustomizationTypeScreenshotShowcase = 7,
KEProfileCustomizationTypeCustomText = 8,
KEProfileCustomizationTypeFavoriteGroup = 9,
KEProfileCustomizationTypeRecommendation = 10,
KEProfileCustomizationTypeWorkshopItem = 11,
KEProfileCustomizationTypeMyWorkshop = 12,
KEProfileCustomizationTypeArtworkShowcase = 13,
KEProfileCustomizationTypeVideoShowcase = 14,
KEProfileCustomizationTypeGuides = 15,
KEProfileCustomizationTypeMyGuides = 16,
KEProfileCustomizationTypeAchievements = 17,
KEProfileCustomizationTypeGreenlight = 18,
KEProfileCustomizationTypeMyGreenlight = 19,
KEProfileCustomizationTypeSalien = 20,
KEProfileCustomizationTypeLoyaltyRewardReactions = 21,
KEProfileCustomizationTypeSingleArtworkShowcase = 22,
KEProfileCustomizationTypeAchievementsCompletionist = 23,
KEProfileCustomizationTypeReplay = 24,
}Variants
KEProfileCustomizationTypeInvalid = 0
KEProfileCustomizationTypeRareAchievementShowcase = 1
KEProfileCustomizationTypeGameCollector = 2
KEProfileCustomizationTypeItemShowcase = 3
KEProfileCustomizationTypeTradeShowcase = 4
KEProfileCustomizationTypeBadges = 5
KEProfileCustomizationTypeFavoriteGame = 6
KEProfileCustomizationTypeScreenshotShowcase = 7
KEProfileCustomizationTypeCustomText = 8
KEProfileCustomizationTypeFavoriteGroup = 9
KEProfileCustomizationTypeRecommendation = 10
KEProfileCustomizationTypeWorkshopItem = 11
KEProfileCustomizationTypeMyWorkshop = 12
KEProfileCustomizationTypeArtworkShowcase = 13
KEProfileCustomizationTypeVideoShowcase = 14
KEProfileCustomizationTypeGuides = 15
KEProfileCustomizationTypeMyGuides = 16
KEProfileCustomizationTypeAchievements = 17
KEProfileCustomizationTypeGreenlight = 18
KEProfileCustomizationTypeMyGreenlight = 19
KEProfileCustomizationTypeSalien = 20
KEProfileCustomizationTypeLoyaltyRewardReactions = 21
KEProfileCustomizationTypeSingleArtworkShowcase = 22
KEProfileCustomizationTypeAchievementsCompletionist = 23
KEProfileCustomizationTypeReplay = 24
Implementations
Sourceimpl EProfileCustomizationType
impl EProfileCustomizationType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EProfileCustomizationType.
Sourcepub fn from_i32(value: i32) -> Option<EProfileCustomizationType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EProfileCustomizationType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EProfileCustomizationType, or None if value is not a valid variant.
Sourceimpl EProfileCustomizationType
impl EProfileCustomizationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.