#[repr(i32)]pub enum EProtoAppType {
Show 20 variants
KEAppTypeInvalid = 0,
KEAppTypeGame = 1,
KEAppTypeApplication = 2,
KEAppTypeTool = 4,
KEAppTypeDemo = 8,
KEAppTypeDeprected = 16,
KEAppTypeDlc = 32,
KEAppTypeGuide = 64,
KEAppTypeDriver = 128,
KEAppTypeConfig = 256,
KEAppTypeHardware = 512,
KEAppTypeFranchise = 1_024,
KEAppTypeVideo = 2_048,
KEAppTypePlugin = 4_096,
KEAppTypeMusicAlbum = 8_192,
KEAppTypeSeries = 16_384,
KEAppTypeComic = 32_768,
KEAppTypeBeta = 65_536,
KEAppTypeShortcut = 1_073_741_824,
KEAppTypeDepotOnly = -2_147_483_648,
}Variants
KEAppTypeInvalid = 0
KEAppTypeGame = 1
KEAppTypeApplication = 2
KEAppTypeTool = 4
KEAppTypeDemo = 8
KEAppTypeDeprected = 16
KEAppTypeDlc = 32
KEAppTypeGuide = 64
KEAppTypeDriver = 128
KEAppTypeConfig = 256
KEAppTypeHardware = 512
KEAppTypeFranchise = 1_024
KEAppTypeVideo = 2_048
KEAppTypePlugin = 4_096
KEAppTypeMusicAlbum = 8_192
KEAppTypeSeries = 16_384
KEAppTypeComic = 32_768
KEAppTypeBeta = 65_536
KEAppTypeShortcut = 1_073_741_824
KEAppTypeDepotOnly = -2_147_483_648
Implementations
Sourceimpl EProtoAppType
impl EProtoAppType
Sourceimpl EProtoAppType
impl EProtoAppType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.