#[repr(i32)]pub enum EPublishedFileQueryType {
Show 24 variants
KPublishedFileQueryTypeRankedByVote = 0,
KPublishedFileQueryTypeRankedByPublicationDate = 1,
KPublishedFileQueryTypeAcceptedForGameRankedByAcceptanceDate = 2,
KPublishedFileQueryTypeRankedByTrend = 3,
KPublishedFileQueryTypeFavoritedByFriendsRankedByPublicationDate = 4,
KPublishedFileQueryTypeCreatedByFriendsRankedByPublicationDate = 5,
KPublishedFileQueryTypeRankedByNumTimesReported = 6,
KPublishedFileQueryTypeCreatedByFollowedUsersRankedByPublicationDate = 7,
KPublishedFileQueryTypeNotYetRated = 8,
KPublishedFileQueryTypeRankedByTotalUniqueSubscriptions = 9,
KPublishedFileQueryTypeRankedByTotalVotesAsc = 10,
KPublishedFileQueryTypeRankedByVotesUp = 11,
KPublishedFileQueryTypeRankedByTextSearch = 12,
KPublishedFileQueryTypeRankedByPlaytimeTrend = 13,
KPublishedFileQueryTypeRankedByTotalPlaytime = 14,
KPublishedFileQueryTypeRankedByAveragePlaytimeTrend = 15,
KPublishedFileQueryTypeRankedByLifetimeAveragePlaytime = 16,
KPublishedFileQueryTypeRankedByPlaytimeSessionsTrend = 17,
KPublishedFileQueryTypeRankedByLifetimePlaytimeSessions = 18,
KPublishedFileQueryTypeRankedByInappropriateContentRating = 19,
KPublishedFileQueryTypeRankedByBanContentCheck = 20,
KPublishedFileQueryTypeRankedByLastUpdatedDate = 21,
KPublishedFileQueryTypeRankedByNumParentItems = 22,
KPublishedFileQueryTypeRankedByNumParentCollections = 23,
}Variants
KPublishedFileQueryTypeRankedByVote = 0
KPublishedFileQueryTypeRankedByPublicationDate = 1
KPublishedFileQueryTypeAcceptedForGameRankedByAcceptanceDate = 2
KPublishedFileQueryTypeRankedByTrend = 3
KPublishedFileQueryTypeFavoritedByFriendsRankedByPublicationDate = 4
KPublishedFileQueryTypeCreatedByFriendsRankedByPublicationDate = 5
KPublishedFileQueryTypeRankedByNumTimesReported = 6
KPublishedFileQueryTypeCreatedByFollowedUsersRankedByPublicationDate = 7
KPublishedFileQueryTypeNotYetRated = 8
KPublishedFileQueryTypeRankedByTotalUniqueSubscriptions = 9
KPublishedFileQueryTypeRankedByTotalVotesAsc = 10
KPublishedFileQueryTypeRankedByVotesUp = 11
KPublishedFileQueryTypeRankedByTextSearch = 12
KPublishedFileQueryTypeRankedByPlaytimeTrend = 13
KPublishedFileQueryTypeRankedByTotalPlaytime = 14
KPublishedFileQueryTypeRankedByAveragePlaytimeTrend = 15
KPublishedFileQueryTypeRankedByLifetimeAveragePlaytime = 16
KPublishedFileQueryTypeRankedByPlaytimeSessionsTrend = 17
KPublishedFileQueryTypeRankedByLifetimePlaytimeSessions = 18
KPublishedFileQueryTypeRankedByInappropriateContentRating = 19
KPublishedFileQueryTypeRankedByBanContentCheck = 20
KPublishedFileQueryTypeRankedByLastUpdatedDate = 21
KPublishedFileQueryTypeRankedByNumParentItems = 22
KPublishedFileQueryTypeRankedByNumParentCollections = 23
Implementations
Sourceimpl EPublishedFileQueryType
impl EPublishedFileQueryType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EPublishedFileQueryType.
Sourcepub fn from_i32(value: i32) -> Option<EPublishedFileQueryType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EPublishedFileQueryType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EPublishedFileQueryType, or None if value is not a valid variant.
Sourceimpl EPublishedFileQueryType
impl EPublishedFileQueryType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.