#[repr(i32)]pub enum ESystemAudioPortType {
KSystemAudioPortTypeInvalid = 0,
KSystemAudioPortTypeUnknown = 1,
KSystemAudioPortTypeAudio32f = 2,
KSystemAudioPortTypeMidi8b = 3,
KSystemAudioPortTypeVideo32Rgba = 4,
}Variants
KSystemAudioPortTypeInvalid = 0
KSystemAudioPortTypeUnknown = 1
KSystemAudioPortTypeAudio32f = 2
KSystemAudioPortTypeMidi8b = 3
KSystemAudioPortTypeVideo32Rgba = 4
Implementations
Sourceimpl ESystemAudioPortType
impl ESystemAudioPortType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ESystemAudioPortType.
Sourcepub fn from_i32(value: i32) -> Option<ESystemAudioPortType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ESystemAudioPortType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ESystemAudioPortType, or None if value is not a valid variant.
Sourceimpl ESystemAudioPortType
impl ESystemAudioPortType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.