pub struct CFriendMessagesIncomingMessageNotification {
pub steamid_friend: Option<u64>,
pub chat_entry_type: Option<i32>,
pub from_limited_account: Option<bool>,
pub message: Option<String>,
pub rtime32_server_timestamp: Option<u32>,
pub ordinal: Option<u32>,
pub local_echo: Option<bool>,
pub message_no_bbcode: Option<String>,
pub low_priority: Option<bool>,
}Fields
steamid_friend: Option<u64>chat_entry_type: Option<i32>from_limited_account: Option<bool>message: Option<String>rtime32_server_timestamp: Option<u32>ordinal: Option<u32>local_echo: Option<bool>message_no_bbcode: Option<String>low_priority: Option<bool>Implementations
Sourceimpl CFriendMessagesIncomingMessageNotification
impl CFriendMessagesIncomingMessageNotification
Sourcepub fn steamid_friend(&self) -> u64
pub fn steamid_friend(&self) -> u64
Returns the value of steamid_friend, or the default value if steamid_friend is unset.
Sourcepub fn chat_entry_type(&self) -> i32
pub fn chat_entry_type(&self) -> i32
Returns the value of chat_entry_type, or the default value if chat_entry_type is unset.
Sourcepub fn from_limited_account(&self) -> bool
pub fn from_limited_account(&self) -> bool
Returns the value of from_limited_account, or the default value if from_limited_account is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn rtime32_server_timestamp(&self) -> u32
pub fn rtime32_server_timestamp(&self) -> u32
Returns the value of rtime32_server_timestamp, or the default value if rtime32_server_timestamp is unset.
Sourcepub fn ordinal(&self) -> u32
pub fn ordinal(&self) -> u32
Returns the value of ordinal, or the default value if ordinal is unset.
Sourcepub fn local_echo(&self) -> bool
pub fn local_echo(&self) -> bool
Returns the value of local_echo, or the default value if local_echo is unset.
Sourcepub fn message_no_bbcode(&self) -> &str
pub fn message_no_bbcode(&self) -> &str
Returns the value of message_no_bbcode, or the default value if message_no_bbcode is unset.
Sourcepub fn low_priority(&self) -> bool
pub fn low_priority(&self) -> bool
Returns the value of low_priority, or the default value if low_priority is unset.