pub struct CFriendMessagesReportMessageRequest {
pub steamid_from: Option<u64>,
pub steamid_to: Option<u64>,
pub timestamp: Option<u32>,
pub ordinal: Option<u32>,
pub report_reason: Option<i32>,
pub report_text: Option<String>,
pub language: Option<String>,
}Fields
steamid_from: Option<u64>steamid_to: Option<u64>timestamp: Option<u32>ordinal: Option<u32>report_reason: Option<i32>report_text: Option<String>language: Option<String>Implementations
Sourceimpl CFriendMessagesReportMessageRequest
impl CFriendMessagesReportMessageRequest
Sourcepub fn steamid_from(&self) -> u64
pub fn steamid_from(&self) -> u64
Returns the value of steamid_from, or the default value if steamid_from is unset.
Sourcepub fn steamid_to(&self) -> u64
pub fn steamid_to(&self) -> u64
Returns the value of steamid_to, or the default value if steamid_to is unset.
Sourcepub fn timestamp(&self) -> u32
pub fn timestamp(&self) -> u32
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn ordinal(&self) -> u32
pub fn ordinal(&self) -> u32
Returns the value of ordinal, or the default value if ordinal is unset.
Sourcepub fn report_reason(&self) -> EContentReportReason
pub fn report_reason(&self) -> EContentReportReason
Returns the enum value of report_reason, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_report_reason(&mut self, value: EContentReportReason)
pub fn set_report_reason(&mut self, value: EContentReportReason)
Sets report_reason to the provided enum value.
Sourcepub fn report_text(&self) -> &str
pub fn report_text(&self) -> &str
Returns the value of report_text, or the default value if report_text is unset.