pub struct CFriendMessagesResolveReportRequest {
pub steamid_from: Option<u64>,
pub steamid_to: Option<u64>,
pub subject_group_id: Option<u64>,
pub subject_id: Option<u64>,
pub resolution: Option<i32>,
pub reason: Option<i32>,
pub skip_lock: Option<bool>,
}Fields
steamid_from: Option<u64>steamid_to: Option<u64>subject_group_id: Option<u64>subject_id: Option<u64>resolution: Option<i32>reason: Option<i32>skip_lock: Option<bool>Implementations
Sourceimpl CFriendMessagesResolveReportRequest
impl CFriendMessagesResolveReportRequest
Sourcepub fn steamid_from(&self) -> u64
pub fn steamid_from(&self) -> u64
Returns the value of steamid_from, or the default value if steamid_from is unset.
Sourcepub fn steamid_to(&self) -> u64
pub fn steamid_to(&self) -> u64
Returns the value of steamid_to, or the default value if steamid_to is unset.
Sourcepub fn subject_group_id(&self) -> u64
pub fn subject_group_id(&self) -> u64
Returns the value of subject_group_id, or the default value if subject_group_id is unset.
Sourcepub fn subject_id(&self) -> u64
pub fn subject_id(&self) -> u64
Returns the value of subject_id, or the default value if subject_id is unset.
Sourcepub fn resolution(&self) -> EContentReportResolution
pub fn resolution(&self) -> EContentReportResolution
Returns the enum value of resolution, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: EContentReportResolution)
pub fn set_resolution(&mut self, value: EContentReportResolution)
Sets resolution to the provided enum value.
Sourcepub fn reason(&self) -> EContentReportReason
pub fn reason(&self) -> EContentReportReason
Returns the enum value of reason, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: EContentReportReason)
pub fn set_reason(&mut self, value: EContentReportReason)
Sets reason to the provided enum value.