pub struct CMsgClientConnectionStats {
pub stats_logon: Option<StatsLogon>,
pub stats_vconn: Option<StatsVConn>,
}Fields
stats_logon: Option<StatsLogon>stats_vconn: Option<StatsVConn>Trait Implementations
Sourceimpl Clone for CMsgClientConnectionStats
impl Clone for CMsgClientConnectionStats
Sourcefn clone(&self) -> CMsgClientConnectionStats
fn clone(&self) -> CMsgClientConnectionStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CMsgClientConnectionStats
Sourceimpl Debug for CMsgClientConnectionStats
impl Debug for CMsgClientConnectionStats
Sourceimpl Default for CMsgClientConnectionStats
impl Default for CMsgClientConnectionStats
impl Eq for CMsgClientConnectionStats
Sourceimpl Hash for CMsgClientConnectionStats
impl Hash for CMsgClientConnectionStats
Sourceimpl Message for CMsgClientConnectionStats
impl Message for CMsgClientConnectionStats
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CMsgClientConnectionStats
impl PartialEq for CMsgClientConnectionStats
Sourcefn eq(&self, other: &CMsgClientConnectionStats) -> bool
fn eq(&self, other: &CMsgClientConnectionStats) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CMsgClientConnectionStats