pub struct CMsgClientFriendMsg {
pub steamid: Option<u64>,
pub chat_entry_type: Option<i32>,
pub message: Option<Vec<u8>>,
pub rtime32_server_timestamp: Option<u32>,
pub echo_to_sender: Option<bool>,
}Fields
steamid: Option<u64>chat_entry_type: Option<i32>message: Option<Vec<u8>>rtime32_server_timestamp: Option<u32>echo_to_sender: Option<bool>Implementations
Sourceimpl CMsgClientFriendMsg
impl CMsgClientFriendMsg
Sourcepub fn steamid(&self) -> u64
pub fn steamid(&self) -> u64
Returns the value of steamid, or the default value if steamid is unset.
Sourcepub fn chat_entry_type(&self) -> i32
pub fn chat_entry_type(&self) -> i32
Returns the value of chat_entry_type, or the default value if chat_entry_type is unset.
Sourcepub fn message(&self) -> &[u8] ⓘ
pub fn message(&self) -> &[u8] ⓘ
Returns the value of message, or the default value if message is unset.
Sourcepub fn rtime32_server_timestamp(&self) -> u32
pub fn rtime32_server_timestamp(&self) -> u32
Returns the value of rtime32_server_timestamp, or the default value if rtime32_server_timestamp is unset.
Sourcepub fn echo_to_sender(&self) -> bool
pub fn echo_to_sender(&self) -> bool
Returns the value of echo_to_sender, or the default value if echo_to_sender is unset.