pub struct CMsgClientP2pConnectionInfo {
pub steam_id_dest: Option<u64>,
pub steam_id_src: Option<u64>,
pub app_id: Option<u32>,
pub candidate: Option<Vec<u8>>,
pub legacy_connection_id_src: Option<u64>,
pub rendezvous: Option<Vec<u8>>,
pub app_id_secondary: Option<u32>,
}Fields
steam_id_dest: Option<u64>steam_id_src: Option<u64>app_id: Option<u32>candidate: Option<Vec<u8>>legacy_connection_id_src: Option<u64>rendezvous: Option<Vec<u8>>app_id_secondary: Option<u32>Implementations
Sourceimpl CMsgClientP2pConnectionInfo
impl CMsgClientP2pConnectionInfo
Sourcepub fn steam_id_dest(&self) -> u64
pub fn steam_id_dest(&self) -> u64
Returns the value of steam_id_dest, or the default value if steam_id_dest is unset.
Sourcepub fn steam_id_src(&self) -> u64
pub fn steam_id_src(&self) -> u64
Returns the value of steam_id_src, or the default value if steam_id_src is unset.
Sourcepub fn app_id(&self) -> u32
pub fn app_id(&self) -> u32
Returns the value of app_id, or the default value if app_id is unset.
Sourcepub fn candidate(&self) -> &[u8] ⓘ
pub fn candidate(&self) -> &[u8] ⓘ
Returns the value of candidate, or the default value if candidate is unset.
Sourcepub fn legacy_connection_id_src(&self) -> u64
pub fn legacy_connection_id_src(&self) -> u64
Returns the value of legacy_connection_id_src, or the default value if legacy_connection_id_src is unset.
Sourcepub fn rendezvous(&self) -> &[u8] ⓘ
pub fn rendezvous(&self) -> &[u8] ⓘ
Returns the value of rendezvous, or the default value if rendezvous is unset.
Sourcepub fn app_id_secondary(&self) -> u32
pub fn app_id_secondary(&self) -> u32
Returns the value of app_id_secondary, or the default value if app_id_secondary is unset.