pub struct CMsgClientWalletInfoUpdate {
pub has_wallet: Option<bool>,
pub balance: Option<i32>,
pub currency: Option<i32>,
pub balance_delayed: Option<i32>,
pub balance64: Option<i64>,
pub balance64_delayed: Option<i64>,
pub realm: Option<i32>,
}Fields
has_wallet: Option<bool>balance: Option<i32>currency: Option<i32>balance_delayed: Option<i32>balance64: Option<i64>balance64_delayed: Option<i64>realm: Option<i32>Implementations
Sourceimpl CMsgClientWalletInfoUpdate
impl CMsgClientWalletInfoUpdate
Sourcepub fn has_wallet(&self) -> bool
pub fn has_wallet(&self) -> bool
Returns the value of has_wallet, or the default value if has_wallet is unset.
Sourcepub fn balance(&self) -> i32
pub fn balance(&self) -> i32
Returns the value of balance, or the default value if balance is unset.
Sourcepub fn currency(&self) -> i32
pub fn currency(&self) -> i32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn balance_delayed(&self) -> i32
pub fn balance_delayed(&self) -> i32
Returns the value of balance_delayed, or the default value if balance_delayed is unset.
Sourcepub fn balance64(&self) -> i64
pub fn balance64(&self) -> i64
Returns the value of balance64, or the default value if balance64 is unset.
Sourcepub fn balance64_delayed(&self) -> i64
pub fn balance64_delayed(&self) -> i64
Returns the value of balance64_delayed, or the default value if balance64_delayed is unset.