pub struct CPackageReservationStatus {
pub packageid: Option<u32>,
pub reservation_state: Option<i32>,
pub queue_position: Option<i32>,
pub total_queue_size: Option<i32>,
pub reservation_country_code: Option<String>,
pub expired: Option<bool>,
pub time_expires: Option<u32>,
pub time_reserved: Option<u32>,
pub rtime_estimated_notification: Option<u32>,
pub notificaton_token: Option<String>,
pub queue_head_position_at_reservation: Option<i32>,
pub queue_head_position_now: Option<i32>,
}Fields
packageid: Option<u32>reservation_state: Option<i32>queue_position: Option<i32>total_queue_size: Option<i32>reservation_country_code: Option<String>expired: Option<bool>time_expires: Option<u32>time_reserved: Option<u32>rtime_estimated_notification: Option<u32>notificaton_token: Option<String>queue_head_position_at_reservation: Option<i32>queue_head_position_now: Option<i32>Implementations
Sourceimpl CPackageReservationStatus
impl CPackageReservationStatus
Sourcepub fn packageid(&self) -> u32
pub fn packageid(&self) -> u32
Returns the value of packageid, or the default value if packageid is unset.
Sourcepub fn reservation_state(&self) -> i32
pub fn reservation_state(&self) -> i32
Returns the value of reservation_state, or the default value if reservation_state is unset.
Sourcepub fn queue_position(&self) -> i32
pub fn queue_position(&self) -> i32
Returns the value of queue_position, or the default value if queue_position is unset.
Sourcepub fn total_queue_size(&self) -> i32
pub fn total_queue_size(&self) -> i32
Returns the value of total_queue_size, or the default value if total_queue_size is unset.
Sourcepub fn reservation_country_code(&self) -> &str
pub fn reservation_country_code(&self) -> &str
Returns the value of reservation_country_code, or the default value if reservation_country_code is unset.
Sourcepub fn expired(&self) -> bool
pub fn expired(&self) -> bool
Returns the value of expired, or the default value if expired is unset.
Sourcepub fn time_expires(&self) -> u32
pub fn time_expires(&self) -> u32
Returns the value of time_expires, or the default value if time_expires is unset.
Sourcepub fn time_reserved(&self) -> u32
pub fn time_reserved(&self) -> u32
Returns the value of time_reserved, or the default value if time_reserved is unset.
Sourcepub fn rtime_estimated_notification(&self) -> u32
pub fn rtime_estimated_notification(&self) -> u32
Returns the value of rtime_estimated_notification, or the default value if rtime_estimated_notification is unset.
Sourcepub fn notificaton_token(&self) -> &str
pub fn notificaton_token(&self) -> &str
Returns the value of notificaton_token, or the default value if notificaton_token is unset.
Sourcepub fn queue_head_position_at_reservation(&self) -> i32
pub fn queue_head_position_at_reservation(&self) -> i32
Returns the value of queue_head_position_at_reservation, or the default value if queue_head_position_at_reservation is unset.
Sourcepub fn queue_head_position_now(&self) -> i32
pub fn queue_head_position_now(&self) -> i32
Returns the value of queue_head_position_now, or the default value if queue_head_position_now is unset.