pub struct CSupportRefreshTokenDescription {
pub token_id: Option<u64>,
pub token_description: Option<String>,
pub time_updated: Option<u32>,
pub platform_type: Option<i32>,
pub token_state: Option<i32>,
pub owner_steamid: Option<u64>,
pub os_platform: Option<u32>,
pub os_type: Option<i32>,
pub auth_type: Option<u32>,
pub gaming_device_type: Option<u32>,
pub first_seen: Option<TokenUsageEvent>,
pub last_seen: Option<TokenUsageEvent>,
}Fields
token_id: Option<u64>token_description: Option<String>time_updated: Option<u32>platform_type: Option<i32>token_state: Option<i32>owner_steamid: Option<u64>os_platform: Option<u32>os_type: Option<i32>auth_type: Option<u32>gaming_device_type: Option<u32>first_seen: Option<TokenUsageEvent>last_seen: Option<TokenUsageEvent>Implementations
Sourceimpl CSupportRefreshTokenDescription
impl CSupportRefreshTokenDescription
Sourcepub fn token_id(&self) -> u64
pub fn token_id(&self) -> u64
Returns the value of token_id, or the default value if token_id is unset.
Sourcepub fn token_description(&self) -> &str
pub fn token_description(&self) -> &str
Returns the value of token_description, or the default value if token_description is unset.
Sourcepub fn time_updated(&self) -> u32
pub fn time_updated(&self) -> u32
Returns the value of time_updated, or the default value if time_updated is unset.
Sourcepub fn platform_type(&self) -> EAuthTokenPlatformType
pub fn platform_type(&self) -> EAuthTokenPlatformType
Returns the enum value of platform_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_platform_type(&mut self, value: EAuthTokenPlatformType)
pub fn set_platform_type(&mut self, value: EAuthTokenPlatformType)
Sets platform_type to the provided enum value.
Sourcepub fn token_state(&self) -> EAuthTokenState
pub fn token_state(&self) -> EAuthTokenState
Returns the enum value of token_state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_token_state(&mut self, value: EAuthTokenState)
pub fn set_token_state(&mut self, value: EAuthTokenState)
Sets token_state to the provided enum value.
Sourcepub fn owner_steamid(&self) -> u64
pub fn owner_steamid(&self) -> u64
Returns the value of owner_steamid, or the default value if owner_steamid is unset.
Sourcepub fn os_platform(&self) -> u32
pub fn os_platform(&self) -> u32
Returns the value of os_platform, or the default value if os_platform is unset.
Sourcepub fn os_type(&self) -> i32
pub fn os_type(&self) -> i32
Returns the value of os_type, or the default value if os_type is unset.
Sourcepub fn auth_type(&self) -> u32
pub fn auth_type(&self) -> u32
Returns the value of auth_type, or the default value if auth_type is unset.
Sourcepub fn gaming_device_type(&self) -> u32
pub fn gaming_device_type(&self) -> u32
Returns the value of gaming_device_type, or the default value if gaming_device_type is unset.