pub struct GamePerformanceSettings {
pub setting: Option<i32>,
pub game_resolution_width: Option<u32>,
pub game_resolution_height: Option<u32>,
}Fields
setting: Option<i32>game_resolution_width: Option<u32>game_resolution_height: Option<u32>Implementations
Sourceimpl GamePerformanceSettings
impl GamePerformanceSettings
Sourcepub fn setting(&self) -> EGamePerformanceSetting
pub fn setting(&self) -> EGamePerformanceSetting
Returns the enum value of setting, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_setting(&mut self, value: EGamePerformanceSetting)
pub fn set_setting(&mut self, value: EGamePerformanceSetting)
Sets setting to the provided enum value.
Sourcepub fn game_resolution_width(&self) -> u32
pub fn game_resolution_width(&self) -> u32
Returns the value of game_resolution_width, or the default value if game_resolution_width is unset.
Sourcepub fn game_resolution_height(&self) -> u32
pub fn game_resolution_height(&self) -> u32
Returns the value of game_resolution_height, or the default value if game_resolution_height is unset.