pub struct CMsgProtoBufHeader {Show 35 fields
pub steamid: Option<u64>,
pub client_sessionid: Option<i32>,
pub routing_appid: Option<u32>,
pub jobid_source: Option<u64>,
pub jobid_target: Option<u64>,
pub target_job_name: Option<String>,
pub seq_num: Option<i32>,
pub eresult: Option<i32>,
pub error_message: Option<String>,
pub auth_account_flags: Option<u32>,
pub token_source: Option<u32>,
pub admin_spoofing_user: Option<bool>,
pub transport_error: Option<i32>,
pub messageid: Option<u64>,
pub publisher_group_id: Option<u32>,
pub sysid: Option<u32>,
pub webapi_key_id: Option<u32>,
pub is_from_external_source: Option<bool>,
pub forward_to_sysid: Vec<u32>,
pub cm_sysid: Option<u32>,
pub launcher_type: Option<u32>,
pub realm: Option<u32>,
pub timeout_ms: Option<i32>,
pub debug_source: Option<String>,
pub debug_source_string_index: Option<u32>,
pub token_id: Option<u64>,
pub routing_gc: Option<CMsgGcRoutingProtoBufHeader>,
pub session_disposition: Option<i32>,
pub wg_token: Option<String>,
pub webui_auth_key: Option<String>,
pub exclude_client_sessionids: Vec<i32>,
pub admin_request_spoofing_steamid: Option<u64>,
pub is_valveds: Option<bool>,
pub trace_tag: Option<u64>,
pub ip_addr: Option<IpAddr>,
}Fields
steamid: Option<u64>client_sessionid: Option<i32>routing_appid: Option<u32>jobid_source: Option<u64>jobid_target: Option<u64>target_job_name: Option<String>seq_num: Option<i32>eresult: Option<i32>error_message: Option<String>auth_account_flags: Option<u32>token_source: Option<u32>admin_spoofing_user: Option<bool>transport_error: Option<i32>messageid: Option<u64>publisher_group_id: Option<u32>sysid: Option<u32>webapi_key_id: Option<u32>is_from_external_source: Option<bool>forward_to_sysid: Vec<u32>cm_sysid: Option<u32>launcher_type: Option<u32>realm: Option<u32>timeout_ms: Option<i32>debug_source: Option<String>debug_source_string_index: Option<u32>token_id: Option<u64>routing_gc: Option<CMsgGcRoutingProtoBufHeader>session_disposition: Option<i32>wg_token: Option<String>webui_auth_key: Option<String>exclude_client_sessionids: Vec<i32>admin_request_spoofing_steamid: Option<u64>is_valveds: Option<bool>trace_tag: Option<u64>ip_addr: Option<IpAddr>Implementations
Sourceimpl CMsgProtoBufHeader
impl CMsgProtoBufHeader
Sourcepub fn steamid(&self) -> u64
pub fn steamid(&self) -> u64
Returns the value of steamid, or the default value if steamid is unset.
Sourcepub fn client_sessionid(&self) -> i32
pub fn client_sessionid(&self) -> i32
Returns the value of client_sessionid, or the default value if client_sessionid is unset.
Sourcepub fn routing_appid(&self) -> u32
pub fn routing_appid(&self) -> u32
Returns the value of routing_appid, or the default value if routing_appid is unset.
Sourcepub fn jobid_source(&self) -> u64
pub fn jobid_source(&self) -> u64
Returns the value of jobid_source, or the default value if jobid_source is unset.
Sourcepub fn jobid_target(&self) -> u64
pub fn jobid_target(&self) -> u64
Returns the value of jobid_target, or the default value if jobid_target is unset.
Sourcepub fn target_job_name(&self) -> &str
pub fn target_job_name(&self) -> &str
Returns the value of target_job_name, or the default value if target_job_name is unset.
Sourcepub fn eresult(&self) -> i32
pub fn eresult(&self) -> i32
Returns the value of eresult, or the default value if eresult is unset.
Sourcepub fn error_message(&self) -> &str
pub fn error_message(&self) -> &str
Returns the value of error_message, or the default value if error_message is unset.
Sourcepub fn auth_account_flags(&self) -> u32
pub fn auth_account_flags(&self) -> u32
Returns the value of auth_account_flags, or the default value if auth_account_flags is unset.
Sourcepub fn transport_error(&self) -> i32
pub fn transport_error(&self) -> i32
Returns the value of transport_error, or the default value if transport_error is unset.
Sourcepub fn messageid(&self) -> u64
pub fn messageid(&self) -> u64
Returns the value of messageid, or the default value if messageid is unset.
Sourcepub fn publisher_group_id(&self) -> u32
pub fn publisher_group_id(&self) -> u32
Returns the value of publisher_group_id, or the default value if publisher_group_id is unset.
Sourcepub fn token_source(&self) -> u32
pub fn token_source(&self) -> u32
Returns the value of token_source, or the default value if token_source is unset.
Sourcepub fn admin_spoofing_user(&self) -> bool
pub fn admin_spoofing_user(&self) -> bool
Returns the value of admin_spoofing_user, or the default value if admin_spoofing_user is unset.
Sourcepub fn seq_num(&self) -> i32
pub fn seq_num(&self) -> i32
Returns the value of seq_num, or the default value if seq_num is unset.
Sourcepub fn webapi_key_id(&self) -> u32
pub fn webapi_key_id(&self) -> u32
Returns the value of webapi_key_id, or the default value if webapi_key_id is unset.
Sourcepub fn is_from_external_source(&self) -> bool
pub fn is_from_external_source(&self) -> bool
Returns the value of is_from_external_source, or the default value if is_from_external_source is unset.
Sourcepub fn cm_sysid(&self) -> u32
pub fn cm_sysid(&self) -> u32
Returns the value of cm_sysid, or the default value if cm_sysid is unset.
Sourcepub fn launcher_type(&self) -> u32
pub fn launcher_type(&self) -> u32
Returns the value of launcher_type, or the default value if launcher_type is unset.
Sourcepub fn timeout_ms(&self) -> i32
pub fn timeout_ms(&self) -> i32
Returns the value of timeout_ms, or the default value if timeout_ms is unset.
Sourcepub fn debug_source(&self) -> &str
pub fn debug_source(&self) -> &str
Returns the value of debug_source, or the default value if debug_source is unset.
Sourcepub fn debug_source_string_index(&self) -> u32
pub fn debug_source_string_index(&self) -> u32
Returns the value of debug_source_string_index, or the default value if debug_source_string_index is unset.
Sourcepub fn token_id(&self) -> u64
pub fn token_id(&self) -> u64
Returns the value of token_id, or the default value if token_id is unset.
Sourcepub fn session_disposition(&self) -> ESessionDisposition
pub fn session_disposition(&self) -> ESessionDisposition
Returns the enum value of session_disposition, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_session_disposition(&mut self, value: ESessionDisposition)
pub fn set_session_disposition(&mut self, value: ESessionDisposition)
Sets session_disposition to the provided enum value.
Sourcepub fn wg_token(&self) -> &str
pub fn wg_token(&self) -> &str
Returns the value of wg_token, or the default value if wg_token is unset.
Sourcepub fn webui_auth_key(&self) -> &str
pub fn webui_auth_key(&self) -> &str
Returns the value of webui_auth_key, or the default value if webui_auth_key is unset.
Sourcepub fn admin_request_spoofing_steamid(&self) -> u64
pub fn admin_request_spoofing_steamid(&self) -> u64
Returns the value of admin_request_spoofing_steamid, or the default value if admin_request_spoofing_steamid is unset.
Sourcepub fn is_valveds(&self) -> bool
pub fn is_valveds(&self) -> bool
Returns the value of is_valveds, or the default value if is_valveds is unset.