pub struct UserSystemInformation {Show 19 fields
pub manufacturer: Option<String>,
pub model: Option<String>,
pub dx_video_card: Option<String>,
pub dx_vendorid: Option<i32>,
pub dx_deviceid: Option<i32>,
pub num_gpu: Option<u32>,
pub system_ram: Option<u64>,
pub os: Option<String>,
pub cpu_vendor: Option<String>,
pub cpu_name: Option<String>,
pub gaming_device_type: Option<u32>,
pub dx_driver_version: Option<String>,
pub adapter_description: Option<String>,
pub driver_version: Option<String>,
pub driver_date: Option<String>,
pub vram_size: Option<u32>,
pub screen_width: Option<u32>,
pub screen_height: Option<u32>,
pub precise_frame_rate: Option<bool>,
}Fields
manufacturer: Option<String>model: Option<String>dx_video_card: Option<String>dx_vendorid: Option<i32>dx_deviceid: Option<i32>num_gpu: Option<u32>system_ram: Option<u64>os: Option<String>cpu_vendor: Option<String>cpu_name: Option<String>gaming_device_type: Option<u32>dx_driver_version: Option<String>adapter_description: Option<String>driver_version: Option<String>driver_date: Option<String>vram_size: Option<u32>screen_width: Option<u32>screen_height: Option<u32>precise_frame_rate: Option<bool>Implementations
Sourceimpl UserSystemInformation
impl UserSystemInformation
Sourcepub fn manufacturer(&self) -> &str
pub fn manufacturer(&self) -> &str
Returns the value of manufacturer, or the default value if manufacturer is unset.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn dx_video_card(&self) -> &str
pub fn dx_video_card(&self) -> &str
Returns the value of dx_video_card, or the default value if dx_video_card is unset.
Sourcepub fn dx_vendorid(&self) -> i32
pub fn dx_vendorid(&self) -> i32
Returns the value of dx_vendorid, or the default value if dx_vendorid is unset.
Sourcepub fn dx_deviceid(&self) -> i32
pub fn dx_deviceid(&self) -> i32
Returns the value of dx_deviceid, or the default value if dx_deviceid is unset.
Sourcepub fn num_gpu(&self) -> u32
pub fn num_gpu(&self) -> u32
Returns the value of num_gpu, or the default value if num_gpu is unset.
Sourcepub fn system_ram(&self) -> u64
pub fn system_ram(&self) -> u64
Returns the value of system_ram, or the default value if system_ram is unset.
Sourcepub fn cpu_vendor(&self) -> &str
pub fn cpu_vendor(&self) -> &str
Returns the value of cpu_vendor, or the default value if cpu_vendor is unset.
Sourcepub fn cpu_name(&self) -> &str
pub fn cpu_name(&self) -> &str
Returns the value of cpu_name, or the default value if cpu_name is unset.
Sourcepub fn gaming_device_type(&self) -> u32
pub fn gaming_device_type(&self) -> u32
Returns the value of gaming_device_type, or the default value if gaming_device_type is unset.
Sourcepub fn dx_driver_version(&self) -> &str
pub fn dx_driver_version(&self) -> &str
Returns the value of dx_driver_version, or the default value if dx_driver_version is unset.
Sourcepub fn adapter_description(&self) -> &str
pub fn adapter_description(&self) -> &str
Returns the value of adapter_description, or the default value if adapter_description is unset.
Sourcepub fn driver_version(&self) -> &str
pub fn driver_version(&self) -> &str
Returns the value of driver_version, or the default value if driver_version is unset.
Sourcepub fn driver_date(&self) -> &str
pub fn driver_date(&self) -> &str
Returns the value of driver_date, or the default value if driver_date is unset.
Sourcepub fn vram_size(&self) -> u32
pub fn vram_size(&self) -> u32
Returns the value of vram_size, or the default value if vram_size is unset.
Sourcepub fn screen_width(&self) -> u32
pub fn screen_width(&self) -> u32
Returns the value of screen_width, or the default value if screen_width is unset.
Sourcepub fn screen_height(&self) -> u32
pub fn screen_height(&self) -> u32
Returns the value of screen_height, or the default value if screen_height is unset.
Sourcepub fn precise_frame_rate(&self) -> bool
pub fn precise_frame_rate(&self) -> bool
Returns the value of precise_frame_rate, or the default value if precise_frame_rate is unset.